@@ -87,7 +87,7 @@ def exec_command(rg, cg, cont, command, max_retries):
     subprocess.Popen(["tmux", "send-keys", "-t", cont,
                     f"az container exec -g {rg} -n {cg} --container-name {cont} --exec-command /bin/bash", "Enter",
                     ], env=env)
-    time.sleep(15)
+    time.sleep(5)
     subprocess.Popen(["tmux", "send-keys", "-t", cont, f"nohup python3 -m acido.cli -sh '{command}' > temp &", "Enter"], env=env)
     time.sleep(2)
     subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
@@ -111,6 +111,7 @@ def exec_command(rg, cg, cont, command, max_retries):
         subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
         time.sleep(5)
         output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env).decode()
+        print(output)
 
         if 'Done' in output:
             break
